@@ -1,5 +1,5 @@
 package WWW::Eksi;
-$WWW::Eksi::VERSION = '0.25';
+$WWW::Eksi::VERSION = '0.26';
 =head1 NAME
 
 WWW::Eksi - Interface for Eksisozluk.com
@@ -18,8 +18,11 @@ Provides easy access to entries and lists of entries.
   my @ghebe_fast = $e->ghebe;    # might get rate limited
   my @ghebe_slow = $e->ghebe(5); # add a politeness delay
 
+  # Yesterday's most popular entries
+  my @doludolu   = $e->doludolu(5);
+
   # Single entry
-  my %entry   = $e->download_entry(1);
+  my $entry   = $e->download_entry(1);
 
 =cut
 
@@ -46,13 +49,19 @@ Returns a new WWW::Eksi object.
 =cut
 
 sub new{
-  return bless {
+  my $class = shift;
+  my $today = DateTime->now->ymd;
+
+  my $eksi = {
     base     => 'https://www.eksisozluk.com',
     entry    => 'https://www.eksisozluk.com/entry/',
     ghebe    => 'https://www.eksisozluk.com/istatistik/gecen-haftanin-en-begenilen-entryleri',
     strp_dt  => DateTime::Format::Strptime->new( pattern => '%d.%m.%Y%H:%M'),
     strp_d   => DateTime::Format::Strptime->new( pattern => '%d.%m.%Y'),
-  }, shift;
+    doludolu => 'https://eksisozluk.com/basliklar/ara?SearchForm.When.From='.$today.'T00:00:00&SearchForm.When.To='.$today.'T23:59:59&SearchForm.SortOrder=Count',
+  };
+
+  return bless $eksi, $class;
 }
 
 =head2 download_entry($id)
@@ -83,10 +92,22 @@ sub download_entry{
   my ($self,$id) = @_;
   my $data = $self->_download($self->{entry}.$id) if ($id && $id=~/^\d{1,}$/);
   return unless $data;
+  return $self->_parse_entry($data,$id);
+}
+
+sub _parse_entry{
+  my ($self,$data, $id) = @_;
+  return unless $data;
 
   my $e = {};
   my $dom = Mojo::DOM->new($data);
 
+  unless ($id){
+    $id = $dom->at('a[class~=entry-date]')->{href};
+    $id =~ s/[^\d]//g;
+    return unless ($id && $id=~/^\d{1,}$/);
+  }
+
   # entry_url
   $e->{entry_url}      = $self->{entry}.$id;
 
@@ -188,6 +209,38 @@ sub ghebe{
   return @ghebe;
 }
 
+=head2 doludolu($politeness_delay)
+
+Returns an array of entries for top posts of yesterday.
+Ordered from more popular to less popular.
+This is an alternative list to DEBE, which is discontinued.
+
+=cut
+
+sub doludolu{
+  my $self      = shift;
+  my $sleep_sec = shift // 0;
+  my $data      = $self->_download($self->{doludolu});
+  my @doludolu  = ();
+  return unless $data;
+
+  my $dom   = Mojo::DOM->new($data);
+  my $links = $dom
+            ->at('ul[class=topic-list]')
+            ->find('a')
+            ->map(sub{$_->{href}=~m/^(.*)\?/})
+            ->to_array;
+
+  foreach my $link (@$links){
+    my $entry_html = $self->_download($self->{base}.$link.'?a=dailynice');
+    my $entry_hash = $self->_parse_entry($entry_html);
+    push @doludolu, $entry_hash;
+    sleep $sleep_sec;
+  }
+
+  return @doludolu;
+}
+
 sub _download{
   my ($self,$url) = @_;
 
